==> otp-react-redux-3.4.2.tgz: package/lib/components/mobile/batch-results-screen.js <==
import coreUtils from '@opentripplanner/core-utils'
import React from 'react'
import { Button } from 'react-bootstrap'
import { connect } from 'react-redux'
import styled, { css } from 'styled-components'

import * as uiActions from '../../actions/ui'
import Map from '../map/map'
import Icon from '../narrative/icon'
import NarrativeItineraries from '../narrative/narrative-itineraries'
import {
  getActiveItineraries,
  getActiveSearch,
  getResponsesWithErrors
} from '../../util/state'

import MobileContainer from './container'
import ResultsError from './results-error'
import ResultsHeader from './results-header'

const StyledMobileContainer = styled(MobileContainer)`
  .options > .header {
    margin: 10px;
  }

  &.otp.mobile .mobile-narrative-container {
    bottom: 0;
    left: 0;
    overflow-y: auto;
    padding: 0;
    position: fixed;
    right: 0;
  }
`

const ExpandMapButton = styled(Button)`
  bottom: 10px;
  left: 10px;
  position: absolute;
  z-index: 999999;
`

const NARRATIVE_SPLIT_TOP_PERCENT = 45

// Styles for the results map also include prop-independent styles copied from mobile.css.
const ResultsMap = styled.div`
  bottom: ${props => props.expanded ? '0' : `${100 - NARRATIVE_SPLIT_TOP_PERCENT}%`};
  display: ${props => props.visible ? 'inherit' : 'none'};
  left: 0;
  position: fixed;
  right: 0;
  top: 100px;
`

const narrativeCss = css`
  top: ${props => props.visible ? (props.expanded ? '100px' : `${NARRATIVE_SPLIT_TOP_PERCENT}%`) : '100%'};
  transition: top 300ms;
`

const StyledResultsError = styled(ResultsError)`
  display: ${props => props.visible ? 'inherit' : 'none'};
  ${narrativeCss}
`

const NarrativeContainer = styled.div`
  ${narrativeCss}
`

const { ItineraryView } = uiActions

/**
 * This component renders the mobile view of itinerary results from batch routing,
 * and features a split view between the map and itinerary results or narratives.
 */
const BatchMobileResultsScreen = ({
  errors,
  itineraries,
  itineraryView,
  toggleBatchResultsMap
}) => {
  const hasErrorsAndNoResult = itineraries.length === 0 && errors.length > 0
  const mapExpanded = itineraryView === ItineraryView.LEG_HIDDEN || itineraryView === ItineraryView.LIST_HIDDEN
  const itineraryExpanded = itineraryView === ItineraryView.FULL

  return (
    <StyledMobileContainer>
      <ResultsHeader />
      <ResultsMap
        expanded={mapExpanded}
        visible={!itineraryExpanded}
      >
        <Map />
        <ExpandMapButton
          bsSize='small'
          onClick={toggleBatchResultsMap}
        >
          <Icon name={mapExpanded ? 'list-ul' : 'arrows-alt'} />{' '}
          {mapExpanded ? 'Show results' : 'Expand map'}
        </ExpandMapButton>
      </ResultsMap>
      {hasErrorsAndNoResult
        ? <StyledResultsError
          error={errors[0]}
          expanded={itineraryExpanded}
          visible={!mapExpanded}
        />
        : (
          <NarrativeContainer
            className='mobile-narrative-container'
            expanded={itineraryExpanded}
            visible={!mapExpanded}
          >
            <NarrativeItineraries
              containerStyle={{
                background: '#fff',
                display: 'flex',
                flexDirection: 'column',
                height: '100%',
                width: '100%'
              }}
            />
          </NarrativeContainer>
        )
      }
    </StyledMobileContainer>
  )
}

// connect to the redux store

const mapStateToProps = (state, ownProps) => {
  const activeSearch = getActiveSearch(state)
  const urlParams = coreUtils.query.getUrlParams()
  return {
    activeLeg: activeSearch ? activeSearch.activeLeg : null,
    errors: getResponsesWithErrors(state),
    itineraries: getActiveItineraries(state),
    itineraryView: urlParams.ui_itineraryView || ItineraryView.LIST
  }
}

const mapDispatchToProps = {
  toggleBatchResultsMap: uiActions.toggleBatchResultsMap
}

export default connect(mapStateToProps, mapDispatchToProps)(BatchMobileResultsScreen)

==> otp-react-redux-3.7.0.tgz: package/lib/components/mobile/batch-results-screen.js <==
import coreUtils from '@opentripplanner/core-utils'
import React from 'react'
import { Button } from 'react-bootstrap'
import { connect } from 'react-redux'
import styled, { css } from 'styled-components'

import * as uiActions from '../../actions/ui'
import Map from '../map/map'
import NarrativeItineraries from '../narrative/narrative-itineraries'
import Icon from '../util/icon'
import {
  getActiveItineraries,
  getActiveSearch,
  getResponsesWithErrors
} from '../../util/state'

import MobileContainer from './container'
import ResultsError from './results-error'
import ResultsHeader from './results-header'

const StyledMobileContainer = styled(MobileContainer)`
  .options > .header {
    margin: 10px;
  }

  &.otp.mobile .mobile-narrative-container {
    bottom: 0;
    left: 0;
    overflow-y: auto;
    padding: 0;
    position: fixed;
    right: 0;
  }
`

const ExpandMapButton = styled(Button)`
  bottom: 10px;
  left: 10px;
  position: absolute;
  z-index: 999999;
`

const NARRATIVE_SPLIT_TOP_PERCENT = 45

// Styles for the results map also include prop-independent styles copied from mobile.css.
const ResultsMap = styled.div`
  bottom: ${props => props.expanded ? '0' : `${100 - NARRATIVE_SPLIT_TOP_PERCENT}%`};
  display: ${props => props.visible ? 'inherit' : 'none'};
  left: 0;
  position: fixed;
  right: 0;
  top: 100px;
`

const narrativeCss = css`
  top: ${props => props.visible ? (props.expanded ? '100px' : `${NARRATIVE_SPLIT_TOP_PERCENT}%`) : '100%'};
  transition: top 300ms;
`

const StyledResultsError = styled(ResultsError)`
  display: ${props => props.visible ? 'inherit' : 'none'};
  ${narrativeCss}
`

const NarrativeContainer = styled.div`
  ${narrativeCss}
`

const { ItineraryView } = uiActions

/**
 * This component renders the mobile view of itinerary results from batch routing,
 * and features a split view between the map and itinerary results or narratives.
 */
const BatchMobileResultsScreen = ({
  errors,
  itineraries,
  itineraryView,
  toggleBatchResultsMap
}) => {
  const hasErrorsAndNoResult = itineraries.length === 0 && errors.length > 0
  const mapExpanded = itineraryView === ItineraryView.LEG_HIDDEN || itineraryView === ItineraryView.LIST_HIDDEN
  const itineraryExpanded = itineraryView === ItineraryView.FULL

  return (
    <StyledMobileContainer>
      <ResultsHeader />
      <ResultsMap
        expanded={mapExpanded}
        visible={!itineraryExpanded}
      >
        <Map />
        <ExpandMapButton
          bsSize='small'
          onClick={toggleBatchResultsMap}
        >
          <Icon name={mapExpanded ? 'list-ul' : 'arrows-alt'} />{' '}
          {mapExpanded ? 'Show results' : 'Expand map'}
        </ExpandMapButton>
      </ResultsMap>
      {hasErrorsAndNoResult
        ? <StyledResultsError
          error={errors[0]}
          expanded={itineraryExpanded}
          visible={!mapExpanded}
        />
        : (
          <NarrativeContainer
            className='mobile-narrative-container'
            expanded={itineraryExpanded}
            visible={!mapExpanded}
          >
            <NarrativeItineraries
              containerStyle={{
                background: '#fff',
                display: 'flex',
                flexDirection: 'column',
                height: '100%',
                width: '100%'
              }}
            />
          </NarrativeContainer>
        )
      }
    </StyledMobileContainer>
  )
}

// connect to the redux store

const mapStateToProps = (state, ownProps) => {
  const activeSearch = getActiveSearch(state)
  const urlParams = coreUtils.query.getUrlParams()
  return {
    activeLeg: activeSearch ? activeSearch.activeLeg : null,
    errors: getResponsesWithErrors(state),
    itineraries: getActiveItineraries(state),
    itineraryView: urlParams.ui_itineraryView || ItineraryView.LIST
  }
}

const mapDispatchToProps = {
  toggleBatchResultsMap: uiActions.toggleBatchResultsMap
}

export default connect(mapStateToProps, mapDispatchToProps)(BatchMobileResultsScreen)
